@@ -1,14 +1,15 @@
 package Org::Dump;
 
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.45'; # VERSION
+
 use 5.010;
 use strict;
 use warnings;
-use Log::Any qw($log);
+use Log::Any::IfLOG qw($log);
 
 use String::Escape qw(elide printable);
 
-our $VERSION = '0.44'; # VERSION
-
 sub _dump_ts {
     my ($self, $ts) = @_;
     my $dump = "";
@@ -131,7 +132,7 @@ Org::Dump - Show Org document/element object in a human-friendly format
 
 =head1 VERSION
 
-This document describes version 0.44 of Org::Dump (from Perl distribution Org-Parser), released on 2015-03-14.
+This document describes version 0.45 of Org::Dump (from Perl distribution Org-Parser), released on 2015-08-18.
 
 =head1 FUNCTIONS
 
