@@ -1,11 +1,11 @@
 package Org::Element;
 
-our $DATE = '2015-03-14'; # DATE
-our $VERSION = '0.44'; # VERSION
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.45'; # VERSION
 
 use 5.010;
 use locale;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 use Moo;
 use Scalar::Util qw(refaddr);
 
@@ -179,7 +179,7 @@ Org::Element - Base class for Org document elements
 
 =head1 VERSION
 
-This document describes version 0.44 of Org::Element (from Perl distribution Org-Parser), released on 2015-03-14.
+This document describes version 0.45 of Org::Element (from Perl distribution Org-Parser), released on 2015-08-18.
 
 =head1 SYNOPSIS
 
