@@ -1,11 +1,11 @@
 package Org::Element::Headline;
 
-our $DATE = '2015-03-14'; # DATE
-our $VERSION = '0.44'; # VERSION
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.45'; # VERSION
 
 use 5.010;
 use locale;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 use Moo;
 use experimental 'smartmatch';
 extends 'Org::Element';
@@ -254,7 +254,7 @@ Org::Element::Headline - Represent Org headline
 
 =head1 VERSION
 
-This document describes version 0.44 of Org::Element::Headline (from Perl distribution Org-Parser), released on 2015-03-14.
+This document describes version 0.45 of Org::Element::Headline (from Perl distribution Org-Parser), released on 2015-08-18.
 
 =head1 DESCRIPTION
 
