@@ -1,13 +1,14 @@
 package Org::Element::Table;
 
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.45'; # VERSION
+
 use 5.010;
 use locale;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 use Moo;
 extends 'Org::Element';
 
-our $VERSION = '0.44'; # VERSION
-
 has _dummy => (is => 'rw'); # workaround Moo bug
 
 sub BUILD {
@@ -120,7 +121,7 @@ Org::Element::Table - Represent Org table
 
 =head1 VERSION
 
-This document describes version 0.44 of Org::Element::Table (from Perl distribution Org-Parser), released on 2015-03-14.
+This document describes version 0.45 of Org::Element::Table (from Perl distribution Org-Parser), released on 2015-08-18.
 
 =head1 DESCRIPTION
 
